mod sensors;
mod netspeed;
mod comm;
mod config;
mod external;
mod bar;
mod store;

use comm::{Channel, Message};
use config::Config;
use std::sync::Arc;
use std::sync::mpsc;
use std::thread;

fn main() {
    let cfg = config::load("./panel.toml");
    let cfg = Arc::new(cfg);

    let (tx, rx) = mpsc::channel::<Message>();
    make_thread(&tx, &cfg, external::external);
    make_thread(&tx, &cfg, sensors::sensors);
    make_thread(&tx, &cfg, netspeed::netspeed);

    let mut topbar = bar::Bar::new(true);
    let mut botbar = bar::Bar::new(false);

    let mut data = store::Store::new();

    loop {
        let msg = rx.recv().unwrap();
        data.save(msg);

        topbar.send(&format!("{}%{{r}}{} | {}",
            data.get("title"),
            data.get("netspeed"),
            data.get("sensors")
        ));
        botbar.send(&format!("{}", data.get("cmus")));
    }
}

fn make_thread(tx: &Channel, cfg: &Arc<Config>, func: fn(&Channel, &Config) -> ()) {
    let thread_tx = tx.clone();
    let thread_cfg = cfg.clone();
    thread::spawn(move || {
        func(&thread_tx, &thread_cfg);
    });
}


